@@ -3,9 +3,9 @@ use strict;
 use warnings;
 use base qw{Package::New};
 use Time::HiRes qw{};
-use Math::Round qw{nhimult}; 
+use Math::Round qw{}; 
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 =head1 NAME
 
@@ -32,7 +32,7 @@ We use this package to make measurements at the same time within the minute for
   use warnings;
   use DateTime;
   use Time::HiRes::Sleep::Until;
-  my $su=Time::HiRes::Sleep::Until->new;
+  my $su = Time::HiRes::Sleep::Until->new;
   do {
     print DateTime->now, "\n"; #make a measurment three times a minute
   } while ($su->mark(20));
@@ -46,7 +46,7 @@ Perl One liner
 =head2 new
 
   use Time::HiRes::Sleep::Until;
-  my $su=Time::HiRes::Sleep::Until->new;
+  my $su = Time::HiRes::Sleep::Until->new;
 
 =head1 METHODS
 
@@ -73,9 +73,9 @@ sub epoch {
 
 Sleep until next second mark;
 
-  my $slept=$su->mark(20); # 20 second mark, i.e.  3 times a minute on the 20s
-  my $slept=$su->mark(10); # 10 second mark, i.e.  6 times a minute on the 10s
-  my $slept=$su->mark(6);  #  6 second mark, i.e. 10 times a minute on 0,6,12,...
+  my $slept = $su->mark(20); # 20 second mark, i.e.  3 times a minute on the 20s
+  my $slept = $su->mark(10); # 10 second mark, i.e.  6 times a minute on the 10s
+  my $slept = $su->mark(6);  #  6 second mark, i.e. 10 times a minute on 0,6,12,...
 
 =cut
 
@@ -84,7 +84,7 @@ sub mark {
   my $self  = shift;
   my $mark  = shift || 0;
   die("Error: mark requires parameter to be greater than zero.") unless $mark > 0;
-  my $epoch = nhimult($mark => $time); #next mark
+  my $epoch = Math::Round::nhimult($mark => $time); #next mark
   return $self->epoch($epoch);
 }
 
@@ -92,8 +92,8 @@ sub mark {
 
 Sleep until the provided seconds after the minute
 
-  my $slept=$su->second(0);  #sleep until top of minute
-  my $slept=$su->second(30); #sleep until bottom of minute
+  my $slept = $su->second(0);  #sleep until top of minute
+  my $slept = $su->second(30); #sleep until bottom of minute
 
 =cut
 
@@ -101,7 +101,7 @@ sub second {
   my $time     = Time::HiRes::time();
   my $self     = shift;
   my $second   = shift || 0; #default is top of the minute
-  my $min_next = nhimult(60 => $time);
+  my $min_next = Math::Round::nhimult(60 => $time);
   my $min_last = $min_next - 60;
   return $time < $min_last + $second
            ? $self->epoch($min_last + $second)
@@ -112,12 +112,12 @@ sub second {
 
 Sleep until the top of the minute
 
-  my $slept=$su->top; #alias for $su->second(0);
+  my $slept = $su->top; #alias for $su->second(0);
 
 =cut
 
 sub top {
-  my $self=shift;
+  my $self = shift;
   return $self->second(0);
 }
 
@@ -136,7 +136,7 @@ Method to access Time::HiRes sleep without another import.
 =cut
 
 sub sleep {
-  my $self  = shift;
+  my $self = shift;
   return Time::HiRes::sleep(@_);
 }
 
@@ -146,27 +146,17 @@ The mathematics add a small amount of delay for which we do not account.  Testin
 
 =head1 BUGS
 
-Please log on RT and send an email to the author.
-
-=head1 SUPPORT
-
-DavisNetworks.com supports all Perl applications including this package.
+Please log on GitHub
 
 =head1 AUTHOR
 
   Michael R. Davis
-  CPAN ID: MRDVT
-  Satellite Tracking of People, LLC
-  mdavis@stopllc.com
-  http://www.stopllc.com/
 
 =head1 COPYRIGHT
 
-This program is free software licensed under the...
+MIT License
 
-The General Public License (GPL), Version 2, June 1991
-
-The full text of the license can be found in the LICENSE file included with this module.
+Copyright (c) 2023 Michael R. Davis
 
 =head1 SEE ALSO
 
